//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//


#ifdef G4MULTITHREADED
#include "G4MTRunManager.hh"
#else
#include "G4RunManager.hh"
#endif

#include "G4UImanager.hh"
#include "G4String.hh"

#include "VKPhysicsList.hh"
#include "VKDetectorConstruction.hh"
#include "VKActionInitialization.hh"
#include "VKRecorderRoot.hh"

#ifdef G4VIS_USE
#include "G4VisExecutive.hh"
#endif

#ifdef G4UI_USE
#include "G4UIExecutive.hh"
#endif


int main(int argc, char** argv)
{
    // run manager
    G4RunManager * runManager = new G4RunManager;

    // recorder
    VKRecorderRoot *recorder = new VKRecorderRoot();

    // detector
    runManager->SetUserInitialization(new VKDetectorConstruction());

    // physics
    runManager->SetUserInitialization(new VKPhysicsList());
    
    // action
    runManager->SetUserInitialization(new VKActionInitialization(recorder));

#ifdef G4VIS_USE
    G4VisManager* visManager = new G4VisExecutive;
    // G4VisExecutive can take a verbosity argument - see /vis/verbose guidance.
    // G4VisManager* visManager = new G4VisExecutive("Quiet");
    visManager->Initialize();
#endif

    // get the pointer to the UI manager and set verbosities
    G4UImanager* UImanager = G4UImanager::GetUIpointer();

    // disable optical physics
    UImanager->ApplyCommand("/VK/physics/opticalPhysics false");

    // Only check for overlapping volumes when detector is initialized (above)
    UImanager->ApplyCommand("/VK/detector/volumes/checkOverlaps false");
  
    if (argc==1)
    {
#ifdef G4UI_USE
        G4UIExecutive* ui = new G4UIExecutive(argc, argv);
#ifdef G4VIS_USE
        UImanager->ApplyCommand("/control/execute vis.mac");
#endif
        if (ui->IsGUI())
            UImanager->ApplyCommand("/control/execute gui.mac");
        ui->SessionStart();
        delete ui;
#endif
    }
    else
    {
        G4String command = "/control/execute ";
        G4String filename = argv[1];
        UImanager->ApplyCommand(command+filename);
    }

#ifdef G4VIS_USE
    delete visManager;
#endif

    // job termination
    delete runManager;
    return 0;
}


