
void superimp(Bool_t wait = false)
{
    // output 
    TString ofname = "vk.eps";

    // files
    vector<TString> filename;
    filename.push_back("forbidden_his.root"); 
    filename.push_back("allowed_his.root");
    filename.push_back("summing_his.root");
    filename.push_back("pileup_his.root");
    filename.push_back("muon_his_eff99.root");
    filename.push_back("muon_his_eff99.9.root");
    
    // line width
    vector<Int_t> lineWidth;
    lineWidth.push_back(2); 
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    lineWidth.push_back(1);
    
    // line colors
    vector<Int_t> lineColor;
    lineColor.push_back(1); 
    lineColor.push_back(1);
    lineColor.push_back(1);
    lineColor.push_back(1);
    lineColor.push_back(1);
    lineColor.push_back(1);
    
    // line styles
    vector<Int_t> lineStyle;
    lineStyle.push_back(1); 
    lineStyle.push_back(1);
    lineStyle.push_back(1);
    lineStyle.push_back(1);
    lineStyle.push_back(2);
    lineStyle.push_back(3);

    // fill colors
    vector<Int_t> fillColor;
    fillColor.push_back(lineColor[0]); 
    fillColor.push_back(lineColor[1]);
    fillColor.push_back(lineColor[2]);
    fillColor.push_back(lineColor[3]);
    fillColor.push_back(lineColor[4]);
    fillColor.push_back(lineColor[5]);

    // fill styles
    vector<Int_t> fillStyle;
    fillStyle.push_back(0); 
    fillStyle.push_back(3003);
    fillStyle.push_back(3004);
    fillStyle.push_back(3001);
    fillStyle.push_back(0);
    fillStyle.push_back(0);
    
    // legends
    vector<TString> legend;
    legend.push_back("2^{+}#rightarrow 0^{+}  (br = 1#times10^{-6})"); 
    legend.push_back("2^{+}#rightarrow 2^{+}"); 
    legend.push_back("#beta#gamma summing"); 
    legend.push_back("#beta#beta pile-up  (#tau = 20 ns)");
    legend.push_back("Cosmic-ray #mu  (#epsilon_{v} = 99%)");
    legend.push_back("Cosmic-ray #mu  (#epsilon_{v} = 99.9%)");
    
    // x axis
    Double_t xmin = 5000.;
    Double_t xmax = 7500.;
    
    // y axis
    Double_t ymin = 0;
    Double_t ymax = 20;
    Bool_t logy = true;
    if (logy) {
        ymin = 0.01;
        ymax = 1e3;
    }
    
	// Prepare canvas
    TCanvas *canvas = new TCanvas("c1", "canvas", 900, 700);
    canvas -> Clear();
	gROOT->SetStyle("Plain");
	gPad->UseCurrentStyle();
	gStyle->SetOptStat("");	
	gStyle->SetFillColor(-1); 
	gStyle->SetLegendBorderSize(0); 
	
	Int_t rf = 133; // times new roman, precision=3
	Int_t itf = 13; // italic times new roman, precision=3
	Float_t tsize = 30; // axes title size
	Float_t lsize = 25; // legend and label size
	Int_t lw = 1; // default line width
	
	// Legend
	Double_t xl1=.5, yl1=0.55, xl2=xl1+0.35, yl2=yl1+0.25;
    TLegend *leg = new TLegend(xl1, yl1, xl2, yl2);
    
	canvas->SetFrameBorderMode(0);
	canvas->SetBorderMode(0);
	canvas->SetFillColor(kWhite);
	canvas->SetLeftMargin(0.1); 

	Float_t xmarg = 0.005; // percent of canvas size
	Float_t ymarg = 0.005; // percent of canvas size
	canvas -> Divide(1, 1, xmarg, ymarg);

   	canvas->cd(1); 
   	canvas->cd(1)->SetBottomMargin(0.11); 
   	canvas->cd(1)->SetTopMargin(0.15); 
   	canvas->cd(1)->SetLeftMargin(0.15); 
    canvas->cd(1)->SetTicks(1,1);
    canvas->cd(1)->SetLogy(1);
    

    // loop over files    
    for (Int_t i=0; i<filename.size(); i++) {

        // get histogram 
        TFile *f = TFile::Open(filename[i]);
        TH1F *hS = (TH1F*)gDirectory->Get("hSingles");  
        TH1F *hV = (TH1F*)gDirectory->Get("hVetoed");
        
        // change names
        hS -> SetName(Form("hSingles_%i", i));  
        hV -> SetName(Form("hVetoed_%i", i));  

        // set line and fill properties
        hV -> SetLineWidth(lineWidth[i]);
        hV -> SetLineColor(lineColor[i]);
        hV -> SetLineStyle(lineStyle[i]);
        hV -> SetFillColorAlpha(fillColor[i], 0.60); // 60% transparency
        hV -> SetFillStyle(fillStyle[i]);

        // draw
        TString opt = "";
        if (i>0) opt = "same";
        hV -> Draw(opt);

        // update canvas
        canvas -> Update();

        // "detach" the histograms from file and close file
        hS -> SetDirectory(0); 
        hV -> SetDirectory(0); 
        f -> Close();

        // set log-y axis
        gPad -> SetLogy(logy);
        
        // legend
        TString label = "l";
        if (fillStyle[i] != 0) label = "f";
        leg -> AddEntry(hV, legend[i], label);  
        leg -> SetTextSize(lsize);
        leg -> SetTextFont(rf);
        leg -> SetFillColor(0);
        leg -> Draw("same");            
        
        // wait
        if (wait) gPad->WaitPrimitive(); 

        // title
        hV -> SetTitle("Veikon Kone GEANT4 simulation");
        
        // get rid of stats
        hV -> SetStats(kFALSE);
        
        // axes

        // X axis
        TAxis * xax = hV -> GetXaxis();
        xax->SetTitleColor(kBlack);
        xax->SetTitleFont(rf);
        xax->SetTitleSize(tsize);
        xax->SetLabelFont(rf);
        xax->SetLabelSize(lsize);
        TString s = Form("E (MeV)");
        xax->SetTitle(s);
        xax->SetTitleOffset(1);
        xax->SetLimits(0,15);  // keV -> MeV
        xax->SetRangeUser(xmin/1000, xmax/1000);

        // Y axis
        TAxis * yax = hV -> GetYaxis();
        yax->SetTitleFont(rf);
        yax->SetLabelFont(rf);
        yax->SetTitleSize(tsize);
        yax->SetTitleColor(kBlack);
        yax->SetLabelSize(lsize);
        s = Form("Counts / 50 keV");
        yax->SetTitle(s);
        yax->SetTitleOffset(1.0);
        hV->SetMinimum(ymin);
        hV->SetMaximum(ymax);        
    }  
    
    Double_t xt = xmin + 0.7*(xmax-xmin);
    xt /= 1000;
    Double_t yt = 1.2*ymax;
    TLatex *t1 = new TLatex(xt, yt, "1 week @ 40 kHz");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

/*
    // TEXT
    Double_t xt = xmin;
    Double_t yt = 10*log10(ymax)/6.3 * ymax;
    Double_t incr = 2.5*log10(ymax)/6.3;
    
    TLatex *t1 = new TLatex(xt, yt, "B_{max} = 0.48 T");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

    yt *= incr;
    t1 = new TLatex(xt, yt, "Duration = 1 week");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

    yt *= incr;
    t1 = new TLatex(xt, yt, "^{20}F yield = 40 kHz");  
    t1->SetTextSize(tsize);  
    t1->SetTextAngle(0);  
    t1->SetTextColor(1);  
    t1->SetTextFont(rf);  
    t1->Draw("same"); 

*/ 

    canvas -> Print(ofname);
     
}
