
#include "VKBaseData.hh"

#include <TParameter.h>

using namespace std;


VKBaseData::~VKBaseData() 
{
    // make sure ROOT file has been closed
    if (fOutputFile != NULL && fOutputFile->IsOpen()) fOutputFile->Close();

    // delete pointers
    delete fOutputFile;
    delete fOutputTree;
}


void VKBaseData::CreateOutput(string filename) 
{
    cout << " Creating output file: " << filename << " ..." << endl;

    // random number generator
    fRNG = new TRandom3();

    // create tree
    fOutputFile = new TFile(filename.c_str(), "RECREATE");
    fOutputTree = new TTree("Detector", "Detector data"); 
    CreateOutputBranches(fOutputTree);
    
    // write normalization
    TParameter<double>* pNorm = new TParameter<double>("NORMALIZATION", this->GetNormalization());
    fOutputTree -> GetUserInfo() -> Add(pNorm);
    cout << " Normalization: " << this->GetNormalization() << endl;
    
    // write area
    TParameter<double>* pArea = new TParameter<double>("SOURCE_AREA/cm2", this->GetArea());
    fOutputTree -> GetUserInfo() -> Add(pArea);    
    
    // loop over events and fill output tree
    for (size_t i=0; i<this->GetEntries(); i++) {

        // get event data
        const auto& ev = this -> GetEvent(i);
        _ESout = ev.ES;
        _EVout = ev.EV;
        _PSout = ev.PS;
        _PVout = ev.PV;
        
        // add experimental resolution
        AddEnergyResolution(_ESout);
        AddEnergyResolution(_EVout);

        // fill tree
        fOutputTree -> Fill();
    }

    // write tree to file
    fOutputTree -> Write();
    
    // close output file
    fOutputFile -> Close();
    
    cout << " Done!" << endl;
}


void VKBaseData::CreateOutputBranches(TTree * t) 
{
    t -> Branch("EDepSignal", &_ESout, "_ESout/F");
    t -> Branch("EDepVeto"  , &_EVout,   "_EVout/F");
    t -> Branch("PhotonsSignal", &_PSout, "_PSout/i");
    t -> Branch("PhotonsVeto"  , &_PVout  , "_PVout/i");
}


void VKBaseData::AddEnergyResolution(Float_t& e)
{
    double sigma = this->GetGaussianEnergyResolution() * e / 2.35;   // see Otto et al. (1979)
    if (sigma == 0) return;
    e += fRNG -> Gaus(0, sigma);
    if (e<=0) e = 0;
}
