
#include "VKSummingData.hh"
#include "VKSimData.hh"

using namespace std;


VKSummingData::VKSummingData(string fname1, string fname2)
 : fSigRel(0),
   fArea(0),
   fSd1(new VKSimData(fname1)),
   fSd2(new VKSimData(fname2))
{
    // number of events going to output file
    size_t n1 = fSd1 -> GetEntries();
    size_t n2 = fSd2 -> GetEntries();
    fEntries = TMath::Min(n1, n2);

    // calculate normalization
    double nmax = (double)TMath::Max(n1, n2);
    double norm1 = fSd1 -> GetNormalization();
    double norm2 = fSd2 -> GetNormalization();
    if (nmax > 0) fNormalization = norm1 * norm2 / nmax;
    else {
        fNormalization = 0;
        cout << " Warning: neither input files has any detected events" << endl;
    }
}


VKSummingData::~VKSummingData() 
{
    delete fSd1;
    delete fSd2;
}


const VKEvent& VKSummingData::GetEvent(size_t id)
{
    size_t i1 = id; // loop forward
    size_t i2 = fSd2->GetEntries() - id; // loop backwards 
    const auto& ev1 = fSd1 -> GetEvent(i1);
    const auto& ev2 = fSd2 -> GetEvent(i2);
    fEvent.ES = ev1.ES + ev2.ES;
    fEvent.EV = ev1.EV + ev2.EV;
    fEvent.PS = ev1.PS + ev2.PS;
    fEvent.PV = ev1.PV + ev2.PV;
    return fEvent;
}
