//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "VKActionInitialization.hh"

#include "VKPrimaryGeneratorAction.hh"

#include "VKRunAction.hh"
#include "VKEventAction.hh"
#include "VKTrackingAction.hh"
#include "VKSteppingAction.hh"
#include "VKStackingAction.hh"
#include "VKSteppingVerbose.hh"

#include "VKRecorderBase.hh"


VKActionInitialization::VKActionInitialization(VKRecorderBase* recorder)
 : G4VUserActionInitialization(), 
   fRecorder(recorder)
{
    // do nothing
}


VKActionInitialization::~VKActionInitialization()
{
    // do nothing
}


void VKActionInitialization::BuildForMaster() const
{
    SetUserAction(new VKRunAction(fRecorder));
}


void VKActionInitialization::Build() const
{
    SetUserAction(new VKPrimaryGeneratorAction());
    SetUserAction(new VKStackingAction());
    SetUserAction(new VKRunAction(fRecorder));
    SetUserAction(new VKEventAction(fRecorder));
    SetUserAction(new VKTrackingAction(fRecorder));
    SetUserAction(new VKSteppingAction(fRecorder));
}


G4VSteppingVerbose* VKActionInitialization::InitializeSteppingVerbose() const
{
    return new VKSteppingVerbose();
}
