//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
#include "VKEMPhysics.hh"

#include "globals.hh"
#include "G4ios.hh"
#include <iomanip>


VKEMPhysics::VKEMPhysics(const G4String& name)
 :  G4VPhysicsConstructor(name)
{
    // do nothing
}


VKEMPhysics::~VKEMPhysics() 
{
    // do nothing
}


#include "G4ParticleDefinition.hh"
#include "G4ParticleTable.hh"

#include "G4Gamma.hh"

#include "G4Electron.hh"
#include "G4Positron.hh"

#include "G4NeutrinoE.hh"
#include "G4AntiNeutrinoE.hh"

void VKEMPhysics::ConstructParticle()
{
    // gamma
    G4Gamma::GammaDefinition();

    // electron
    G4Electron::ElectronDefinition();
    G4Positron::PositronDefinition();
    G4NeutrinoE::NeutrinoEDefinition();
    G4AntiNeutrinoE::AntiNeutrinoEDefinition();
    
    // optical photon
    G4OpticalPhoton::OpticalPhotonDefinition();
}


#include "G4ProcessManager.hh"

void VKEMPhysics::ConstructProcess()
{
    G4PhotoElectricEffect* fPhotoEffect = new G4PhotoElectricEffect();
    G4ComptonScattering* fComptonEffect = new G4ComptonScattering();
    G4GammaConversion* fPairProduction  = new G4GammaConversion();

    // Electron physics
    G4eMultipleScattering* fElectronMultipleScattering = new G4eMultipleScattering();
    G4eIonisation* fElectronIonisation = new G4eIonisation();
    G4eBremsstrahlung* fElectronBremsStrahlung = new G4eBremsstrahlung();

    // Positron physics
    G4eMultipleScattering* fPositronMultipleScattering = new G4eMultipleScattering();
    G4eIonisation* fPositronIonisation = new G4eIonisation();
    G4eBremsstrahlung* fPositronBremsStrahlung = new G4eBremsstrahlung();
    G4eplusAnnihilation* fAnnihilation = new G4eplusAnnihilation();

    G4ProcessManager* pManager = 0;

    // Gamma Physics
    pManager = G4Gamma::Gamma()->GetProcessManager();
    pManager -> AddDiscreteProcess(fPhotoEffect);
    pManager -> AddDiscreteProcess(fComptonEffect);
    pManager -> AddDiscreteProcess(fPairProduction);

    // Electron Physics
    pManager = G4Electron::Electron()->GetProcessManager();

    pManager -> AddProcess(fElectronMultipleScattering, -1, 1, 1);
    pManager -> AddProcess(fElectronIonisation,         -1, 2, 2);
    pManager -> AddProcess(fElectronBremsStrahlung,     -1, 3, 3);  

    // Positron Physics
    pManager = G4Positron::Positron()->GetProcessManager();

    pManager -> AddProcess(fPositronMultipleScattering, -1, 1, 1);
    pManager -> AddProcess(fPositronIonisation,         -1, 2, 2);
    pManager -> AddProcess(fPositronBremsStrahlung,     -1, 3, 3);  
    pManager -> AddProcess(fAnnihilation,                0,-1, 4);  
}
