//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "VKRunAction.hh"
#include "VKRecorderBase.hh"
#include "VKPrimaryGeneratorAction.hh"

#include "G4RunManager.hh"
#include "G4UImanager.hh"
#include "G4ThreeVector.hh"

#include <TStopwatch.h>


VKRunAction::VKRunAction(VKRecorderBase* r) 
 : fRecorder(r) 
{
    // stop watch
    fStopwatch = new TStopwatch();

    // do nothing
}


VKRunAction::~VKRunAction() 
{
    // do nothing
}


void VKRunAction::BeginOfRunAction(const G4Run* aRun)
{
    fStopwatch -> Reset();
    fStopwatch -> Start();
    G4cout << " ---> Begin run" << G4endl;

    if (fRecorder) fRecorder -> RecordBeginOfRun(aRun);
}


void VKRunAction::EndOfRunAction(const G4Run* aRun)
{
    // run duration
    fStopwatch -> Stop();
    G4cout << " ---> End run" << G4endl;
    G4cout << " ---> Run duration: " << Form("%.2f", fStopwatch->RealTime()) << " seconds";
    double rate = aRun->GetNumberOfEventToBeProcessed()/(fStopwatch->RealTime()/3600);
    G4cout << " (" << Form("%.2e", rate) << " events/hour)" << G4endl; 

    // get centre position
    G4RunManager * rm = G4RunManager::GetRunManager();
    const VKPrimaryGeneratorAction * pga = 
        static_cast<const VKPrimaryGeneratorAction*>(rm->GetUserPrimaryGeneratorAction());
    G4ThreeVector p = pga -> GetCentrePosition();
    double x = p.x() /cm;
    double y = p.y() /cm;
    double z = p.z() /cm;

    // reset source centre position
    G4String cmd = Form("/gps/position %f %f %f cm", x, y, z);
    G4UImanager::GetUIpointer() -> ApplyCommand(cmd);

    if (fRecorder) fRecorder -> RecordEndOfRun(aRun);
}
