
#include <unittest++/UnitTest++.h>

#include "VKRecorderRoot.hh"
#include "VKRunAction.hh"

#include "G4RunManager.hh"
#include "G4UImanager.hh"
#include "G4SystemOfUnits.hh"


SUITE(VKEnergyDepositionTest) {

    class SetupFixture {
        public:
            SetupFixture()
            {
                // get pointer to run manager
                runManager = G4RunManager::GetRunManager();
                
                // get pointer to UI manager
                UImanager = G4UImanager::GetUIpointer();
                
                // get pointer to user action
                const VKRunAction *runAction = 
                    static_cast<const VKRunAction*>(runManager->GetUserRunAction()); 
                
                // get pointer to recorder
                recorder = static_cast<const VKRecorderRoot*>(runAction->GetRecorder());

                // keep only beta detector in setup
                UImanager->ApplyCommand("/VK/detector/volumes/betaDetector true");
                UImanager->ApplyCommand("/VK/detector/volumes/magnet false");
                UImanager->ApplyCommand("/VK/detector/volumes/catcherFoil false");
                UImanager->ApplyCommand("/VK/detector/volumes/shield false");

                // do *not* store trajectory data
                UImanager->ApplyCommand("/VK/storeTrajectoryData false");

                // disable magnetic field
                UImanager->ApplyCommand("/VK/field/enable false");
            }
            G4UImanager *UImanager;
            G4RunManager *runManager;
            const VKRecorderRoot *recorder;
    };

    TEST_FIXTURE(SetupFixture, Sanity) {
        CHECK_EQUAL(1, 1);
    }
    
    TEST_FIXTURE(SetupFixture, Test3MeVElectronInsideSignalDetector) {
        G4double edep=0;
        UImanager->ApplyCommand("/gps/direction 0 0 1");
        UImanager->ApplyCommand("/gps/position 0 0 30.5 cm");
        // check energy deposition for 3 MeV electron
        UImanager->ApplyCommand("/gps/particle e-");
        UImanager->ApplyCommand("/gps/energy 3 MeV");
        UImanager->ApplyCommand("/run/beamOn 1");
        edep = recorder -> GetEDepSignal();
        CHECK_CLOSE(3000., edep/keV, 1e-3); 
        // check for 1.5 MeV electron
        UImanager->ApplyCommand("/gps/particle e-");
        UImanager->ApplyCommand("/gps/energy 1.5 MeV");
        UImanager->ApplyCommand("/run/beamOn 1");
        edep = recorder -> GetEDepSignal();
        CHECK_CLOSE(1500., edep/keV, 1e-3); 
    }

    TEST_FIXTURE(SetupFixture, Test1GeVVerticalMuon) {
        UImanager->ApplyCommand("/gps/direction 0 -1 0");
        UImanager->ApplyCommand("/gps/position 0 3.1 32 cm");
        UImanager->ApplyCommand("/gps/particle mu-");
        UImanager->ApplyCommand("/gps/energy 1 GeV");
        UImanager->ApplyCommand("/run/beamOn 1");
        G4double edep = recorder -> GetEDepSignal();
//        CHECK_CLOSE(7.63, edep/MeV, 1e-1); 
        CHECK_CLOSE(18.9, edep/MeV, 2); 
    }
}
